Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2155)

Unified Diff: media/audio/audio_output_ipc.h

Issue 10830268: Allow audio system to handle synchronized low-latency audio I/O (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/audio/audio_output_ipc.h
===================================================================
--- media/audio/audio_output_ipc.h (revision 155437)
+++ media/audio/audio_output_ipc.h (working copy)
@@ -68,10 +68,13 @@
// Sends a request to create an AudioOutputController object in the peer
// process, identify it by |stream_id| and configure it to use the specified
// audio |params|. Once the stream has been created, the implementation must
scherkus (not reviewing) 2012/09/10 11:46:32 remove extra space
Chris Rogers 2012/09/10 19:21:38 Done.
// generate a notification to the AudioOutputIPCDelegate and call
// OnStreamCreated().
- virtual void CreateStream(int stream_id, const AudioParameters& params) = 0;
+ virtual void CreateStream(int stream_id,
+ const AudioParameters& params,
+ int input_channels) = 0;
// Starts playing the stream. This should generate a call to
// AudioOutputController::Play().
@@ -68,10 +68,13 @@
// Sends a request to create an AudioOutputController object in the peer
// process, identify it by |stream_id| and configure it to use the specified
- // audio |params|. Once the stream has been created, the implementation must
+ // audio |params| and number of synchronized input channels.
+ // Once the stream has been created, the implementation must
scherkus (not reviewing) 2012/09/10 11:46:32 remove extra space
Chris Rogers 2012/09/10 19:21:38 Done.

Powered by Google App Engine
This is Rietveld 408576698